=======
Octavia
=======

Operator-grade open source scalable load balancer.

The Octavia project seeks to become the standard operator-grade load balancer
in use in large OpenStack deployments. Note that it is not competing with the
Neutron LBaaS extension and may never actually replace it. Rather, Octavia
should be seen as "yet another vendor" which is accessed via a driver for
Neutron LBaaS.

For more information on project direction and guiding principles for
contributors, please see the CONSTITUTION.rst file in this directory, or
specifications in the specs/ subdirectory. Other documentation can be
found in the docs/ directory.

Please also see https://wiki.openstack.org/wiki/Octavia/Roadmap for the
latest version of our project roadmap.
